@@ -1,5 +1,8 @@
-$self->{CC}="CC -vdelx -pta";
-$self->{LD}="CC -ztext";
+my $cc = '-vdelx -pta';
+my $ld = '-ztext';
+
+$self->{CC}="CC $cc";
+$self->{LD}="CC $ld";
 
 my $dbv = 0;
 if ($dbv >= 1) {
@@ -7,11 +10,9 @@ if ($dbv >= 1) {
 }
 if ($dbv >= 2) {
     # Insure++ is amazing!  http://www.parasoft.com
-    $self->{CC} = "insure -Zoi 'compiler CC' -vdelx -pta";
-    $self->{LD} = "insure -Zoi 'compiler CC' -ztext";
+    $self->{CC} = "insure -Zoi 'compiler CC' $cc";
+    $self->{LD} = "insure -Zoi 'compiler CC' $ld";
 }
 
 $self->{CCCDLFLAGS} = "-KPIC";
 $self->{clean}{FILES} .= ' Templates.DB';
-$self->{PERLMAINCC} = 'gcc';
-
