@@ -120,6 +120,7 @@ sub new {
 }
 
 sub is_evolved {
+    local $Carp::CarpLevel = $Carp::CarpLevel+1;
     my ($o) = @_;
     return 0 if !$o->SUPER::is_evolved();
     ObjStore::AVHV::Fields::is_newest_layout($o);
@@ -159,11 +160,19 @@ sub BLESS {
 
 sub evolve { bless $_[0], ref($_[0]); }
 
-sub readonly {
+#sub readonly {
+#    my ($o,$k) = @_;
+#    my $x = $o->[0]->{$k};
+#    die "Bad index while coercing array into hash ($k)" if $x<1;
+#    $o->SUPER::readonly($x);
+#}
+
+sub POSH_CD {
     my ($o,$k) = @_;
-    my $x = $o->[0]->{$k};
-    die "Bad index while coercing array into hash ($k)" if $x<1;
-    $o->SUPER::readonly($x);
+    return if $k =~ m/^_/;
+    my $fm = $o->[0];
+    return unless exists $fm->{$k};
+    $o->[ $fm->{$k} ];
 }
 
 # Hash style, but in square brackets
